# 个人使用包

## 测试

```python
import jackyutils.test as jtest
jtest.test() # 会打印"successfully test!"
```

## 算法-快速排序

```python
import jackyutils.algorithm.sort.quick_sort as qs
qs.quick_sort([6,10,13,5,8,3,2,11])
```

## 游戏-进度条

```python
import jackyutils.game.bar as bar
bar.print_virus()
```
